@@ -58,7 +58,7 @@ if not sys.warnoptions:
 if sys.platform != "win32":
 	import fcntl
 
-n_version = "8.2.2" # Should also be bumped in pyproject.toml, extra/*.appdata.xml
+n_version = "8.2.3" # Should also be bumped in pyproject.toml, extra/*.appdata.xml
 t_version = "v" + n_version
 t_title = "Tauon"
 t_id = "tauonmb"
@@ -400,7 +400,7 @@ while True:
 		break
 	drivers.append(x)
 
-logging.debug(f"SDL availiable drivers: {drivers}")
+logging.debug(f"SDL available drivers: {drivers}")
 logging.debug(f"PATH that will be used for ffmpeg/ffprobe and similar: {os.environ.get('PATH')}")
 
 driver = None
