@@ -45,7 +45,7 @@ try:
 except ModuleNotFoundError:
 	logging.warning("Unable to import Tekore, Spotify support will be disabled.")
 except Exception:
-	logging.exception("Unkown error trying to import Tekore, Spotify support will be disabled.")
+	logging.exception("Unknown error trying to import Tekore, Spotify support will be disabled.")
 else:
 	tekore_imported = True
 
